# Release 3.0.1369.1

## 批量计算(batch) 版本：2017-03-12

### 第 60 次发布

发布时间：2025-08-07 01:09:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeJobMonitorData](https://cloud.tencent.com/document/api/599/120596)

	* 新增入参：Dimensions


新增数据结构：

* [Dimension](https://cloud.tencent.com/document/api/599/15912#Dimension)



## 腾讯云数据仓库TCHouse-C(cdwch) 版本：2020-09-15

### 第 32 次发布

发布时间：2025-08-07 01:13:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceNew](https://cloud.tencent.com/document/api/1299/84353)

	* 新增入参：CkDefaultUserPwd




## 云顾问-混沌演练(cfg) 版本：2021-08-20

### 第 32 次发布

发布时间：2025-08-07 01:14:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTaskFromAction](https://cloud.tencent.com/document/api/1500/109362)

	* 新增入参：TaskTags




## 云安全一体化平台(csip) 版本：2022-11-21

### 第 60 次发布

发布时间：2025-08-07 01:17:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConfigCheckRules](https://cloud.tencent.com/document/api/664/122403)

修改接口：

* [DescribeCallRecord](https://cloud.tencent.com/document/api/664/120726)

	* 新增入参：AccUin


新增数据结构：

* [RiskRuleInfo](https://cloud.tencent.com/document/api/664/90825#RiskRuleInfo)
* [SourceIPVpcInfo](https://cloud.tencent.com/document/api/664/90825#SourceIPVpcInfo)

修改数据结构：

* [CallRecord](https://cloud.tencent.com/document/api/664/90825#CallRecord)

	* 新增成员：VpcInfo

* [ExposesItem](https://cloud.tencent.com/document/api/664/90825#ExposesItem)

	* 新增成员：ExposureID, PortDetectCount, PortDetectResult




## 弹性 MapReduce(emr) 版本：2019-01-03

### 第 118 次发布

发布时间：2025-08-07 01:25:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInsightList](https://cloud.tencent.com/document/api/589/103078)

	* 新增入参：MustHasContext




## 媒体处理(mps) 版本：2019-06-12

### 第 137 次发布

发布时间：2025-08-07 01:37:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LiveStreamAiAnalysisResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiAnalysisResultItem)

	* 新增成员：HighlightResultSet




## 腾讯健康组学平台(omics) 版本：2022-11-28

### 第 23 次发布

发布时间：2025-08-07 01:39:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVolume](https://cloud.tencent.com/document/api/1643/104065)

	* 新增入参：EnableAutoScaleUp, MetaType


新增数据结构：

* [VolumeAutoScaleUpRule](https://cloud.tencent.com/document/api/1643/89100#VolumeAutoScaleUpRule)

修改数据结构：

* [StorageOption](https://cloud.tencent.com/document/api/1643/89100#StorageOption)

	* 新增成员：EnableAutoScaleUp, MetaType

* [Volume](https://cloud.tencent.com/document/api/1643/89100#Volume)

	* 新增成员：AutoScaleUpRule, MetaType, Zone




## 云数据库 SQL Server(sqlserver) 版本：2018-03-28

### 第 74 次发布

发布时间：2025-08-07 01:43:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)

	* 新增出参：IsSafetyLimited, IsSupportSA




## 消息队列 TDMQ(tdmq) 版本：2020-02-17

### 第 155 次发布

发布时间：2025-08-07 01:47:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetRocketMQConsumerOffSet](https://cloud.tencent.com/document/api/1179/71662)

	* 新增入参：RetryFlag

	* <font color="#dd0000">**修改入参**：</font>Topic




## 边缘安全加速平台(teo) 版本：2022-09-01

### 第 116 次发布

发布时间：2025-08-07 01:48:43

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [FrequentScanningProtection](https://cloud.tencent.com/document/api/1552/80721#FrequentScanningProtection)

修改数据结构：

* [ManagedRules](https://cloud.tencent.com/document/api/1552/80721#ManagedRules)

	* 新增成员：FrequentScanningProtection




## 边缘安全加速平台(teo) 版本：2022-01-06



## 消息队列 RocketMQ 版(trocket) 版本：2023-03-08

### 第 43 次发布

发布时间：2025-08-07 01:51:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1493/97868)

	* <font color="#dd0000">**修改入参**：</font>VpcList




## 向量数据库(vdb) 版本：2023-06-16

### 第 15 次发布

发布时间：2025-08-07 01:55:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1709/117430)

	* 新增入参：ProductType

* [ScaleUpInstance](https://cloud.tencent.com/document/api/1709/117423)

	* <font color="#dd0000">**修改入参**：</font>Cpu, Memory, StorageSize




